<?php 
/* 
Plugin Name: JsDataTable
Plugin URI: http://www.web-sky.de/plugin-jsdatatable/
Description: Display data from your wp-posts as an interactive and sortable DataTable on a wp-page. Use regular categories and post tags as a criteria to restrict the number of data records in a DataTable. Customize columns (fields) by shortcode arguments, also including custom fields. Examples and settings like Paging, Ordering, Filtering and other stuff see on <a href="http://www.web-sky.de/plugin-jsdatatable">Plugin-Page http://www.web-sky.de/plugin-jsdatatable</a>. 
Version: 1.3 
Author: Hartmut Albers 
Min WP Version: 4.0 
*/ 


// exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;


// define vars as constants
define( 'JSDATATABLE_URL', plugin_dir_url( __FILE__ ) );
define( 'JSDATATABLE_ABSPATH', plugin_dir_path( __FILE__ ) );


// functions
include_once JSDATATABLE_ABSPATH . '/lib/html_table.php' ;
include_once JSDATATABLE_ABSPATH . '/lib/js_inline_script.php' ;
include_once JSDATATABLE_ABSPATH . '/lib/little_helpers.php' ;

// custom-css & custom-js
if( !is_admin() ) { 
	add_action( 'wp_enqueue_scripts', 'jsdtab_load_custom_scripts'); 
}


function jsdtab_load_custom_scripts() {
	// add scripts if shortcode is in content
	global $post;
	if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, 'jsdatatable') ) {
		wp_enqueue_style('jsdatatable-style', JSDATATABLE_URL . 'css/jsdatatable.css', false, '1.10.11' );
		wp_enqueue_script( 'jsdatatable-libary', JSDATATABLE_URL . 'js/jquery.dataTables.min.V1.10.11.js', array('jquery') );
	}
}


function jsdtab_build_shortcode ( $atts ) {
		
	//  default shortcode-settings
	$s = shortcode_atts( array ( 

		/* SOME BASIC PLUGIN SETTINGS */
		'lang' => '',						// Usage: lang='de' +'es' +'fr', custom language, otherwise build-in lang is 'en'  
		'cols' => 'title,published,author',	// Usage: cols='title,published,YourCustomField2,YourCustomField1,author' 
		'headline' => '',					// Usage: headline='YourOwnHeadingTxt2,YourOwnHeadingTxt1,YourOwnHeadingTxt3' 
		'head' => null, 					// argument 'head' is just a short acronym for 'headline'
		'category' => 'MISSING',			// Usage: category='mercedes,bmw,porsche,...', pull posts from this wp_categories
		'cat' => null,						// argument 'cat' is just a short acronym for 'category' 
		'tag' => 'MISSING',					// Usage: tag='convertible,gearing', pull posts with this wp_tags into data table
		
		/* SOME ADVANCED PLUGIN SETTINGS */
		'searching' => 'yes',				// Usage: searching='yes|no' displays searchform (filtering data)
		'ordering' => 'yes',				// Usage: ordering='yes|no' enables ordering-feature in thead <th>
		'orderby' => '',					// Usage: orderby='published,author,title', manipulates default-ordering (cols)
		'order' => '',						// Usage: order='dsc,asc,asc', argument order belongs to orderby
		'sortingcolor' => 'yes',			// Usage: sortingcolor='yes|no' switches on/off color-highlighting of ordered cols
		'sortingcolorstartup' => 'no',		// Usage: sortingcolorstartup='yes|no' controls color-highlighting only at pageload
		'navinfo' => 'yes',					// Usage: navinfo='yes|no' switches off navigation information
		'paging' => 'no',					// Usage: paging='yes|no' switches off paging feature
		'dropdown' => '10,25,50,all',		// Usage: dropdown='YourDropDownCfg' (set PageLenght) | dropdown='no|disable|off'
		'dropdown_all_txt' => 'All',		// Usage: dropdown_all_txt='YourText', the Text in DropDownList instead of word 'All'
		'all' => null, 						// argument 'all' is just a short acronym for 'dropdown_all_txt' 
		'publisheddateformat' => '',		// e.g. "j. F Y" | Y-m-d | http://codex.wordpress.org/Formatting_Date_and_Time
		'pub' => null, 						// argument 'pub' is just a short acronym for 'publisheddateformat'
		'scrollx' => 'no',					// Usage: scrollx='yes|no' activate ability to show tables with horizontal scrolling
		'compact' => 'no',					// Usage: compact='yes|no' reduces height of each table row a bit 
		
		/* SPECIAL SETTINGS TO HANDLE LINK'S IN DATATABLE */
		'linkto' => 'title',				// Usage: linkto='field1,field2,field3' | linkto='all' | linkto='no|disable|off' 
		'ahrefclass' => '',					// your individual name of a 'css-class' for post-links  
		'modal' => '',						// avoid modal even if necessary plugins (Fancybox+ContentOnly) active: 'modal=off'  
		'headline_more_txt' => str_replace(':', '', __('Content:')) ,	// Headingtxt in thead if keyword 'more' appear in 'cols'
		'headmore' => null, 				// argument 'headmore' is just a short acronym for 'headline_more_txt'
		'more_txt' => __('Read more...'),	// More-Linktext (<a href....> + </a>) if field 'more' is in col_listing (cols)
		'more' => null, 					// argument 'more' is just a short acronym for 'more_txt'
	
	), $atts ); 

	// should all fields (columns) in the datatable appear as a link?
	if ( $s['linkto'] == 'all' ) { 
		$s['linkto'] = $s['cols']; 
	}	

	// predefined datelayout's for "en|de|es|fr" if in shortcode "lang=XX" is used (otherwiese default is 'Y-m-d')
	if ( empty($s['publisheddateformat']) ) { 
		$s['publisheddateformat'] = jsdtab_get_default_dateformat( $s['lang'] ); 
	}	
	
	// move acronyms to their suitable args (of course this overwrites args if the args also exits)
	if ( !empty($s['head']) ) 		{ $s['headline'] = $s['head']; 	}
	if ( !empty($s['cat']) ) 		{ $s['category'] = $s['cat']; 	}
	if ( !empty($s['all']) ) 		{ $s['dropdown_all_txt'] = $s['all']; } 
	if ( !empty($s['pub']) ) 		{ $s['publisheddateformat'] = $s['pub']; } 
	if ( !empty($s['headmore']) ) 	{ $s['headline_more_txt'] = $s['headmore']; }	
	if ( !empty($s['more']) )		{ $s['more_txt'] = $s['more']; }

	// exit plugin if shortcode doesn't contains search-condition (no category & no tag)
	if ( $s['category']=='MISSING' && $s['tag']=='MISSING' ) { 
		return '<p>' . __('Plugin JsDataTable: please modify argument in your shortcode (category or tag required)') . '</p>'; 
	}
	
	// convert data to arrays (plugin work environment)
	if ( !empty($s['cols']) ) 		{ $arr_colnames = explode(',', $s['cols']);		} else { $arr_colnames = array(); }
	if ( !empty($s['headline']) ) 	{ $arr_headline = explode(',', $s['headline']); } else { $arr_headline = array(); }
	if ( !empty($s['orderby']) ) 	{ $arr_orderby = explode(',', $s['orderby']); 	} else { $arr_orderby = array(); }
	if ( !empty($s['order']) ) 		{ $arr_order = explode(',', $s['orderby']); 	} else { $arr_order = array(); }
	if ( !empty($s['linkto']) ) 	{ $arr_linkto = explode(',', $s['linkto']); 	} else { $arr_linkto = array(); }

	// some few themes don't have following function onboard
	if ( !function_exists( 'is_plugin_active' ) ) {
		require_once( ABSPATH . '/wp-admin/includes/plugin.php' );  
	}
	
	// display data in modal?
	if ( is_plugin_active( 'easy-fancybox/easy-fancybox.php' ) 
		&& is_plugin_active( 'show-content-only/content-only.php' ) 	
			&& !jsdtab_arg_is_disabled ( $s['modal'] ) ) {
			// (a) wp-plugin 'Easy FancyBox' features cool modal options
			// (b) wp-plugin 'Show Content Only' strips off all wrappers (just expand permalink with '?content-only=1&css=1')
			// (c) in the case to avoid a modal even if both plugins are activated: syntax 'modal=off' in shortcode possible
			$s['ahrefclass'] .= ' fancybox-iframe'; // extend css-class 
			$url_extension = '?content-only=1&css=1'; // extend permalink-url
	} 

	// define WP_Query
	$wp_query_args = array( 'post_type'=>'post', 'post_status'=>'publish', 'posts_per_page'=>-1, );
	if ( $s['category'] != 'all' && $s['category'] != '*' && $s['category'] != 'MISSING' ) { 
		// extend search-condition for WP_Query
		$wp_query_args['category_name'] = $s['category']; 
	}
	if ( $s['tag'] != 'all' && $s['tag'] != '*' && $s['tag'] != 'MISSING' ) { 
		// extend search-condition for WP_Query
		$wp_query_args['tag'] = $s['tag'];  
	}
	
	// run WP_Query
	$my_query = new WP_Query( $wp_query_args );
	if ( $my_query->have_posts() ) : 

		// setup & init the "JsDatatTable" (inline javascript-code within html)
		echo jsdtab_print_inline_jsscript( $s, $arr_colnames, $arr_orderby, $arr_order );
		
		// create head of html-table
		$output = jsdtab_create_tabhead ( $arr_colnames, $arr_headline, $s['headline_more_txt'], $s['scrollx'], $s['compact'] );
	
		// wp-loop
		while ( $my_query->have_posts() ) : $my_query->the_post(); 	
			// display all rows in html-table
			$output .=  jsdtab_create_tabrow ( $arr_colnames, $arr_linkto, $s['linkto'], $s['ahrefclass'], $s['publisheddateformat'], $s['more_txt'], $url_extension );
		endwhile;
		
		// close the html-table
		$output .= jsdtab_create_tabbody();
		
		wp_reset_postdata(); 
	else : 
		$output = '<p>' . __('JsDataTable: Sorry, no data matched criteria') . '</p>';
	endif; 

	return $output;
}
add_shortcode( 'jsdatatable', 'jsdtab_build_shortcode' );

?>